@@ -1,6 +1,7 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
-#include <config.h>
 
 #include <iostream>
 #include <tuple>
@@ -38,7 +39,7 @@ void testCoarsenIndices(int N)
   ParallelIndexSet& indices = pinfo.indexSet();
   RemoteIndices& remoteIndices = pinfo.remoteIndices();
 
-  typedef Dune::CollectiveCommunication<MPI_Comm> Comm;
+  typedef Dune::Communication<MPI_Comm> Comm;
   Comm cc(MPI_COMM_WORLD);
 
   BCRSMat mat = setupAnisotropic2d<Block>(N, indices, cc, &n);
