@@ -1,6 +1,7 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
-#include "config.h"
 
 /*#include"xreal.h"
 
@@ -66,7 +67,7 @@ typedef Dune::BCRSMatrix<MatrixBlock> BCRSMat;
 typedef Dune::FieldVector<XREAL,1> VectorBlock;
 typedef Dune::BlockVector<VectorBlock> Vector;
 typedef Dune::MatrixAdapter<BCRSMat,Vector,Vector> Operator;
-typedef Dune::CollectiveCommunication<void*> Comm;
+typedef Dune::Communication<void*> Comm;
 typedef Dune::SeqSSOR<BCRSMat,Vector,Vector> Smoother;
 typedef Dune::Amg::SmootherTraits<Smoother>::Arguments SmootherArgs;
 
@@ -93,7 +94,7 @@ void *solve(void* arg)
 
   std::cout<<"AMG solving took "<<solvetime<<" seconds"<<std::endl;
 
-  pthread_exit(NULL);
+  return NULL;
 }
 
 void *solve2(void* arg)
@@ -168,8 +169,6 @@ void testAMG(int N, int coarsenTarget, int ml)
   criterion.setMaxLevel(ml);
   criterion.setSkipIsolated(false);
 
-  Dune::SeqScalarProduct<Vector> sp;
-
   Smoother smoother(mat,1,1);
   AMG amg(fop, criterion);
 
