@@ -1,4 +1,5 @@
-#include"config.h"
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 #include "anisotropic.hh"
 #include <dune/common/timer.hh>
 #include <dune/common/shared_ptr.hh>
@@ -32,7 +33,7 @@ typedef Dune::BCRSMatrix<MatrixBlock> BCRSMat;
 typedef Dune::FieldVector<XREAL,1> VectorBlock;
 typedef Dune::BlockVector<VectorBlock> Vector;
 typedef Dune::MatrixAdapter<BCRSMat,Vector,Vector> Operator;
-typedef Dune::CollectiveCommunication<void*> Comm;
+typedef Dune::Communication<void*> Comm;
 typedef Dune::SeqSSOR<BCRSMat,Vector,Vector> Smoother;
 typedef Dune::Amg::SmootherTraits<Smoother>::Arguments SmootherArgs;
 #ifndef USE_OVERLAPPINGSCHWARZ
@@ -74,7 +75,7 @@ void *solve(void* arg)
 
   std::cout<<"AMG solving took "<<solvetime<<" seconds"<<std::endl;
 
-  pthread_exit(NULL);
+  return NULL;
 }
 
 void *solve2(void* arg)
@@ -98,7 +99,7 @@ void testTwoLevelMethod()
     typedef Dune::FieldVector<double,BS> VectorBlock;
     typedef Dune::BlockVector<VectorBlock> Vector;
     typedef Dune::MatrixAdapter<BCRSMat,Vector,Vector> Operator;
-    typedef Dune::CollectiveCommunication<void*> Comm;
+    typedef Dune::Communication<void*> Comm;
     Comm c;
     int n;
     BCRSMat mat = setupAnisotropic2d<MatrixBlock>(N, indices, c, &n, 1);
