@@ -1,6 +1,7 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
-#include "config.h"
 
 // hack to ensure assert() does something
 // really, assert() should not be used in unit tests.
@@ -16,9 +17,7 @@
 #include <memory>
 
 #include <dune/common/classname.hh>
-#if HAVE_MPROTECT
 #include <dune/common/debugallocator.hh>
-#endif
 #include <dune/common/fvector.hh>
 #include <dune/common/poolallocator.hh>
 #include <dune/common/scalarvectorview.hh>
@@ -106,7 +105,7 @@ void testCapacity()
   vec.resize(10);
   for(int i=0; i<10; ++i)
     vec[i]=Dune::BlockVector<SmallVector>(10);
-  ThreeLevelVector vec1=vec;
+  [[maybe_unused]] ThreeLevelVector vec1 = vec;
 }
 
 template <class V>
@@ -183,10 +182,6 @@ int main()
   //typedef double value_type;
   typedef Dune::FieldVector<value_type,1> VectorBlock;
   typedef Dune::BlockVector<VectorBlock> Vector;
-  Vector v;
-  v=0;
-  Dune::BlockVector<Dune::FieldVector<std::complex<double>,1> > v1;
-  v1=0;
 
   // Test a BlockVector of BlockVectors
   typedef Dune::BlockVector<Vector> VectorOfVector;
