@@ -1,6 +1,7 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
-#include "config.h"
 #include<dune/istl/bvector.hh>
 #include<dune/istl/superlu.hh>
 #include<dune/istl/preconditioners.hh>
@@ -17,7 +18,7 @@ int main(int argc, char** argv)
 
   if(argc>1)
     N = atoi(argv[1]);
-  std::cout<<"testing for N="<<N<<" BS="<<1<<std::endl;
+  std::cout << "testing for N=" << N << " BS=" << BS << std::endl;
 
   typedef Dune::FieldMatrix<double,BS,BS> MatrixBlock;
   typedef Dune::BCRSMatrix<MatrixBlock> BCRSMat;
