@@ -1,9 +1,10 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /** \file
     \brief Unit tests for the different dynamic matrices provided by ISTL
  */
-#include "config.h"
 
 #include <fenv.h>
 
@@ -297,8 +298,10 @@ void testTranspose(const MatrixType& matrix)
 int main()
 {
 
-  // feenableexcept does not exist on OS X or windows
-#if not defined( __APPLE__ ) and not defined( __MINGW32__ )
+
+#if defined( __APPLE__ ) or defined( __MINGW32__ ) or defined(_MSC_VER)
+  feraiseexcept(FE_INVALID);
+#else
   feenableexcept(FE_INVALID);
 #endif
 
@@ -480,6 +483,9 @@ int main()
     BDMatrix<double> bdMatrix3 = {1.0, 2.0, 3.0};
     testSolve<BDMatrix<double>, BlockVector<double> >(bdMatrix3);
 
+    // Test whether inversion works
+    bdMatrix3.invert();
+
     // test whether resizing works
     bdMatrix2.setSize(5);
     bdMatrix2 = 4.0;
@@ -487,8 +493,6 @@ int main()
     y.resize(5);
     testMatrix(bdMatrix2, x, y);
 
-    // Test whether inversion works
-    bdMatrix2.invert();
   }
 
   // ////////////////////////////////////////////////////////////////////////
