@@ -1,8 +1,7 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
 #include <iostream>
 #include <dune/common/fmatrix.hh>
 #include <dune/istl/io.hh>
