@@ -1,15 +1,13 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /**
  * \file
  * \brief Test the MultiTypeBlockVector data structure
  */
-
-#if HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include <iostream>
+#include <complex>
 
 #include <dune/common/exceptions.hh>
 #include <dune/common/fvector.hh>
@@ -29,6 +27,20 @@ void testMultiVector(const MultiTypeBlockVector<Args...>& multiVector)
     using size_type = typename MultiTypeBlockVector<Args...>::size_type;
     static_assert(std::numeric_limits<size_type>::is_integer, "size_type is not an integer!");
 
+    // Test whether we can use std::tuple_element
+    {
+      // Do std::tuple_element and operator[] return the same type?
+      using TupleElementType = typename std::tuple_element<0, MultiTypeBlockVector<Args...> >::type;
+      using BracketType = decltype(multiVector[Indices::_0]);
+
+      // As the return type of const operator[], BracketType will always
+      // be a const reference.  We cannot simply strip the const and the &,
+      // because entries of a MultiTypeBlockVector can be references themselves.
+      // Therefore, always add const& to the result of std::tuple_element as well.
+      constexpr bool sameType = std::is_same_v<const TupleElementType&,BracketType>;
+      static_assert(sameType, "std::tuple_element does not provide the type of the 0th MultiTypeBlockVector entry!");
+    }
+
     // test operator<<
     std::cout << multiVector << std::endl;
 
@@ -37,11 +49,6 @@ void testMultiVector(const MultiTypeBlockVector<Args...>& multiVector)
 
     static_assert(MultiTypeBlockVector<Args...>::size()==2, "Method MultiTypeBlockVector::size() returned wrong value!");
 
-DUNE_NO_DEPRECATED_BEGIN
-    if (multiVector.count() != 2)
-      DUNE_THROW(Exception, "Method MultiTypeBlockVector::count returned wrong value!");
-DUNE_NO_DEPRECATED_END
-
     if (multiVector.N() != 2)
       DUNE_THROW(Exception, "Method MultiTypeBlockVector::N returned wrong value!");
 
@@ -97,6 +104,16 @@ int main(int argc, char** argv) try
 
   testMultiVector(multiVectorRef);
 
+  // test field_type (std::common_type) for some combinations
+  static_assert ( std::is_same_v<typename MultiTypeBlockVector<BlockVector<FieldVector<double,3> >, BlockVector<FieldVector<double,1> > >::field_type,
+                                 double > );
+  static_assert ( std::is_same_v<typename MultiTypeBlockVector<BlockVector<FieldVector<float,3> >, BlockVector<FieldVector<float,1> > >::field_type,
+                                 float > );
+  static_assert ( std::is_same_v<typename MultiTypeBlockVector<BlockVector<FieldVector<float,3> >, BlockVector<FieldVector<double,1> > >::field_type,
+                                 double > );
+  static_assert ( std::is_same_v<typename MultiTypeBlockVector<BlockVector<FieldVector<double,3> >, BlockVector<FieldVector<std::complex<double>,1> > >::field_type,
+                                 std::complex<double> > );
+
   return 0;
 }
 catch (Dune::Exception& e)
