@@ -1,6 +1,7 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
-#include <config.h>
 
 #include <complex>
 
@@ -43,8 +44,8 @@ void runSuperLU(std::size_t N)
   solver.setVerbosity(true);
   solver.apply(x,b, res);
 
-  std::set<std::size_t> mrs;
-  for(std::size_t s=0; s < N/2; ++s)
+  std::set<typename Matrix::size_type> mrs;
+  for(typename Matrix::size_type s=0; s < N/2; ++s)
     mrs.insert(s);
 
   solver1.setSubMatrix(mat,mrs);
