@@ -1,6 +1,7 @@
+// SPDX-FileCopyrightText: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
-#include "config.h"
 #include <dune/istl/vbvector.hh>
 #include <dune/common/fvector.hh>
 #include <dune/common/typetraits.hh>
@@ -33,7 +34,7 @@ int main()
     We have to un-initialize it first:
   */
   std::size_t size = 20;
-  v3.resize(size); // this makes v3 unitialized again
+  v3.resize(size); // this makes v3 uninitialized again
 
   // Set block sizes with CreateIterator:
   for (auto cIt = v3.createbegin(); cIt!=v3.createend(); ++cIt)
@@ -85,5 +86,10 @@ int main()
   testVectorSpaceOperations(v5);
   testScalarProduct(v5);
 
+  // check move construction
+  auto v6 = std::move(v4);
+  suite.check(v6.size()==20, "Check size of moved-constructed object");
+  suite.check(v6[0].size() == 8, "Check if blocksize of move constructed vector survived");
+
   return suite.exit();
 }
